seekerpay_split library
Classes
- SplitBill
- A bill-splitting session with a set of participants and their payment statuses.
- SplitBillManager
-
Riverpod
StateNotifierthat manages a list of SplitBill sessions, persisting them toSharedPreferencesand verifying payment status via RPC. - SplitParticipant
- Represents one participant and their share in a split bill.
Enums
- SplitStatus
- Payment status for a single participant in a split bill.
Properties
-
splitBillProvider
→ StateNotifierProvider<
SplitBillManager, List< SplitBill> > -
Provider for SplitBillManager using the current
rpcClientProvider.final